@@ -33,6 +33,6 @@ int main()
 {
     typedef std::multimap<int, double, transparent_less_no_type> M;
 
-    M().equal_range(C2Int{5});
+    TEST_IGNORE_NODISCARD M().equal_range(C2Int{5});
 }
 #endif
